#!/usr/bin/python
import sys

from charmhelpers.core.hookenv import (
    Hooks,
    UnregisteredHookError,
    log,
)
from charmhelpers.fetch import apt_update, apt_install
from charmhelpers.contrib.hardening.harden import harden

hooks = Hooks()


@hooks.hook('install')
@harden()
def install():
    log("Executing charm install hook")
    apt_update(fatal=True)
    apt_install(['mysql-server', 'apache2'])


@hooks.hook('upgrade-charm')
@harden()
def upgrade_charm():
    log("Executing charm upgrade hook")


@hooks.hook('update-status')
@harden()
def update_status():
    # NOTE: this should be run everytime juju status fires (default approx.
    #       every 5 mins)
    pass


if __name__ == '__main__':
    try:
        hooks.execute(sys.argv)
    except UnregisteredHookError as e:
        log('Unknown hook {} - skipping.'.format(e))
